 
# aaa

#def print_lol(the_list):
# bbb
#	for each_item in the_list:
#		if isinstance(each_item,list):
#			print_lol(each_item)
#		else:
#			print(each_item)



def print_lol(the_list,level=0):
    for each_item in the_list:
        if isinstance(each_item,list):
            print_lol(each_item,level+1)
        else:
            for tab_stop in range(level):
                print("\t",end="")
            print(each_item)


from distutils.core import setup

setup(
		name      	 ='nestertest123',
		version 	 ='1.2.1',
		py_modules   =['nestertest123'],
		author  	 ='hfpython',
		author_email ='ceshi@163.com',
		url			 ='http://www.testerhome.com',
		description  ='A simple printer of nested lists', 
	)
